diff --git a/frontend/index.html b/frontend/index.html
index 7bc3514..3d1ef86 100644
--- a/frontend/index.html
+++ b/frontend/index.html
@@ -494,10 +494,10 @@
Stundenhöhe (Wochen- & Tagesansicht)
Wie viel Platz eine Stunde in der Zeitrasteransicht einnimmt
-
-
-
-
+
+
+
+
Ausgeblendete Kalender
diff --git a/frontend/js/utils.js b/frontend/js/utils.js
index 8219e07..7f5caa7 100644
--- a/frontend/js/utils.js
+++ b/frontend/js/utils.js
@@ -92,7 +92,7 @@ export function applyTheme(settings) {
root.style.setProperty('--border', lc.border);
root.style.setProperty('--border-light', lc.light);
- const hh = settings.hour_height || 60;
+ const hh = settings.hour_height || 54;
root.style.setProperty('--hour-h', hh + 'px');
}
diff --git a/frontend/js/calendar.js b/frontend/js/calendar.js
index 081145c..cb8566b 100644
--- a/frontend/js/calendar.js
+++ b/frontend/js/calendar.js
@@ -227,7 +227,7 @@ function renderView() {
showEventPopup,
false,
weekStartDay,
- state.settings.hour_height || 60
+ state.settings.hour_height || 54
);
} else if (state.currentView === 'day') {
renderWeek(container, state.currentDate, evs,
@@ -235,7 +235,7 @@ function renderView() {
showEventPopup,
true,
weekStartDay,
- state.settings.hour_height || 60
+ state.settings.hour_height || 54
);
} else if (state.currentView === 'quarter') {
renderQuarter(container, state.currentDate, evs,
@@ -653,15 +653,15 @@ function bindTopbar() {
document.getElementById('btn-settings').onclick = openSettingsModal;
document.getElementById('btn-create-event').onclick = () => openNewEventModal(new Date());
// Mouse wheel / trackpad scroll navigation (500ms cooldown = 1 nav per gesture)
let _wheelLast = 0;
document.getElementById('view-container').addEventListener('wheel', e => {
+ if (state.currentView !== 'month' && state.currentView !== 'quarter') return;
e.preventDefault();
const now = Date.now();
if (now - _wheelLast < 500) return;
_wheelLast = now;
const dir = e.deltaY > 0 ? 1 : -1;
- if (state.currentView === 'agenda') return;
if (state.currentView === 'month') {
state.currentDate = new Date(state.currentDate);
state.currentDate.setDate(state.currentDate.getDate() + dir * 7);
@@ -1527,7 +1527,7 @@ function bindSettingsModal() {
dim_past_events: document.getElementById('cfg-dim-past').checked,
text_contrast: getActive('cfg-text-contrast') || 3,
line_contrast: getActive('cfg-line-contrast') || 3,
- hour_height: getActive('cfg-hour-height') || 60,
+ hour_height: getActive('cfg-hour-height') || 54,
language: document.getElementById('cfg-language').value,
};
try {
@@ -653,15 +653,15 @@ function bindTopbar() {
document.getElementById('btn-settings').onclick = openSettingsModal;
document.getElementById('btn-create-event').onclick = () => openNewEventModal(new Date());
- // Mouse wheel / trackpad scroll navigation (500ms cooldown = 1 nav per gesture)
+ // Mouse wheel / trackpad scroll navigation – only for month & quarter
let _wheelLast = 0;
document.getElementById('view-container').addEventListener('wheel', e => {